@@ -1,5 +1,6 @@
-import logging
 import requests
+import logging
+from logging import INFO
 from dateutil import parser
 from datetime import datetime
 from dataclasses import dataclass
@@ -229,8 +230,10 @@ class ItemRegistry:
                 return to_item(data)
             elif response.status_code == 404:
                 raise Exception("item " +   uri + " not exists " + response.text)
+            elif response.status_code == 401:
+                raise Exception("auth error. user=" + self.credentials.username)
             else:
-                raise Exception("could not read item state " +   uri +  " got error " + response.text)
+                raise Exception("could not read item state " +  uri +  " got error " + response.text)
         except Exception as e:
             logging.warning("error occurred by calling " + uri, e)
 
@@ -251,6 +254,8 @@ class ItemRegistry:
                 return
             elif response.status_code == 404:
                 raise Exception("item " +   uri + " not exists " + response.text)
+            elif response.status_code == 401:
+                raise Exception("auth error. user=" + self.credentials.username)
             else:
                 raise Exception("could not update item state " +   uri +  " got error " + response.text)
         except Exception as e:
@@ -294,12 +299,12 @@ class ItemRegistry:
     def get_state_as_datetime(self, item_name: str, datetime_string: str="1970-01-01") -> datetime:
         state = self.get_item(item_name)
         if state is None or state.value is None:
-            return datetime.fromtimestamp(parser.parse(datetime_string).timestamp())
+            return parser.parse(datetime_string)
         else:
             return state.get_state_as_datetime()
 
 
-    def set_state(self, item_name: str, new_state, reason: str = "") -> bool:
+    def set_state(self, item_name: str, new_state, reason: str = "", log_level: int = INFO) -> bool:
         if new_state is None:
             logging.warning("try to set " + item_name + " = None. ignoring it")
         else:
@@ -313,7 +318,7 @@ class ItemRegistry:
                 if serialized_old_sate != serialized_new_state:
                     try:
                         self.set_item_state(item_name, serialized_new_state)
-                        logging.info("set " + item_name + " = " + serialized_new_state + " " + reason)
+                        logging.log(log_level, "set " + item_name + " = " + serialized_new_state + " " + reason)
                         return True
                     except Exception as e:
                         logging.warning("could not set " + item_name + " = " + serialized_new_state, e)
